# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_client_chat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.dota_shared_enums_pb2 as dota__shared__enums__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_client_chat.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n!dota_gcmessages_client_chat.proto\x1a\x17\x64ota_shared_enums.proto\"`\n\x1f\x43MsgClientToGCPrivateChatInvite\x12!\n\x19private_chat_channel_name\x18\x01 \x01(\t\x12\x1a\n\x12invited_account_id\x18\x02 \x01(\r\"[\n\x1d\x43MsgClientToGCPrivateChatKick\x12!\n\x19private_chat_channel_name\x18\x01 \x01(\t\x12\x17\n\x0fkick_account_id\x18\x02 \x01(\r\"a\n CMsgClientToGCPrivateChatPromote\x12!\n\x19private_chat_channel_name\x18\x01 \x01(\t\x12\x1a\n\x12promote_account_id\x18\x02 \x01(\r\"_\n\x1f\x43MsgClientToGCPrivateChatDemote\x12!\n\x19private_chat_channel_name\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65mote_account_id\x18\x02 \x01(\r\"\xbd\x04\n!CMsgGCToClientPrivateChatResponse\x12!\n\x19private_chat_channel_name\x18\x01 \x01(\t\x12\x42\n\x06result\x18\x02 \x01(\x0e\x32).CMsgGCToClientPrivateChatResponse.Result:\x07SUCCESS\x12\x10\n\x08username\x18\x03 \x01(\t\"\x9e\x03\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x19\n\x15\x46\x41ILURE_CREATION_LOCK\x10\x01\x12\x1b\n\x17\x46\x41ILURE_SQL_TRANSACTION\x10\x02\x12\x14\n\x10\x46\x41ILURE_SDO_LOAD\x10\x03\x12\x19\n\x15\x46\x41ILURE_NO_PERMISSION\x10\x04\x12\x1a\n\x16\x46\x41ILURE_ALREADY_MEMBER\x10\x05\x12\x18\n\x14\x46\x41ILURE_NOT_A_MEMBER\x10\x07\x12\x1f\n\x1b\x46\x41ILURE_NO_REMAINING_ADMINS\x10\x08\x12\x13\n\x0f\x46\x41ILURE_NO_ROOM\x10\t\x12!\n\x1d\x46\x41ILURE_CREATION_RATE_LIMITED\x10\n\x12 \n\x1c\x46\x41ILURE_UNKNOWN_CHANNEL_NAME\x10\x0b\x12\x18\n\x14\x46\x41ILURE_UNKNOWN_USER\x10\x0c\x12\x19\n\x15\x46\x41ILURE_UNKNOWN_ERROR\x10\r\x12\x1d\n\x19\x46\x41ILURE_CANNOT_KICK_ADMIN\x10\x0e\x12\x19\n\x15\x46\x41ILURE_ALREADY_ADMIN\x10\x0f\"I\n$CMsgClientToGCPrivateChatInfoRequest\x12!\n\x19private_chat_channel_name\x18\x01 \x01(\t\"\xee\x01\n%CMsgGCToClientPrivateChatInfoResponse\x12!\n\x19private_chat_channel_name\x18\x01 \x01(\t\x12>\n\x07members\x18\x02 \x03(\x0b\x32-.CMsgGCToClientPrivateChatInfoResponse.Member\x12\x0f\n\x07\x63reator\x18\x03 \x01(\r\x12\x15\n\rcreation_date\x18\x04 \x01(\r\x1a:\n\x06Member\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\r\"w\n\x17\x43MsgDOTAJoinChatChannel\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x46\n\x0c\x63hannel_type\x18\x04 \x01(\x0e\x32\x16.DOTAChatChannelType_t:\x18\x44OTAChannelType_Regional\".\n\x18\x43MsgDOTALeaveChatChannel\x12\x12\n\nchannel_id\x18\x01 \x01(\x04\"I\n\x1a\x43MsgGCChatReportPublicSpam\x12\x12\n\nchannel_id\x18\x01 \x01(\x04\x12\x17\n\x0f\x63hannel_user_id\x18\x02 \x01(\r\"7\n\x19\x43MsgDOTAClientIgnoredUser\x12\x1a\n\x12ignored_account_id\x18\x01 \x01(\r\"\xb6\x06\n\x13\x43MsgDOTAChatMessage\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x12\n\nchannel_id\x18\x02 \x01(\x04\x12\x14\n\x0cpersona_name\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\r\x12!\n\x19suggest_invite_account_id\x18\x06 \x01(\r\x12\x1b\n\x13suggest_invite_name\x18\x07 \x01(\t\x12&\n\x1e\x66\x61ntasy_draft_owner_account_id\x18\x08 \x01(\r\x12\'\n\x1f\x66\x61ntasy_draft_player_account_id\x18\t \x01(\r\x12\x10\n\x08\x65vent_id\x18\n \x01(\r\x12\x1f\n\x17suggest_invite_to_lobby\x18\x0b \x01(\x08\x12\x14\n\x0c\x65vent_points\x18\x0c \x01(\r\x12\x11\n\tcoin_flip\x18\r \x01(\x08\x12\x15\n\tplayer_id\x18\x0e \x01(\x05:\x02-1\x12 \n\x18share_profile_account_id\x18\x0f \x01(\r\x12\x17\n\x0f\x63hannel_user_id\x18\x10 \x01(\r\x12\x30\n\tdice_roll\x18\x11 \x01(\x0b\x32\x1d.CMsgDOTAChatMessage.DiceRoll\x12\x16\n\x0eshare_party_id\x18\x12 \x01(\x04\x12\x16\n\x0eshare_lobby_id\x18\x13 \x01(\x04\x12\"\n\x1ashare_lobby_custom_game_id\x18\x14 \x01(\x04\x12\x1b\n\x13share_lobby_passkey\x18\x15 \x01(\t\x12\x1f\n\x17private_chat_channel_id\x18\x16 \x01(\r\x12\x0e\n\x06status\x18\x17 \x01(\r\x12\x1a\n\x12\x62\x61ttle_cup_victory\x18\x18 \x01(\x08\x12\x13\n\x0b\x62\x61\x64ge_level\x18\x19 \x01(\r\x12\x1c\n\x14suggest_pick_hero_id\x18\x1a \x01(\r\x12\x1e\n\x16suggest_pick_hero_role\x18\x1b \x01(\t\x1a>\n\x08\x44iceRoll\x12\x10\n\x08roll_min\x18\x01 \x01(\x05\x12\x10\n\x08roll_max\x18\x02 \x01(\x05\x12\x0e\n\x06result\x18\x03 \x01(\x05\"e\n\x12\x43MsgDOTAChatMember\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63hannel_user_id\x18\x03 \x01(\r\x12\x0e\n\x06status\x18\x04 \x01(\r\"\xea\x05\n\x1f\x43MsgDOTAJoinChatChannelResponse\x12\x10\n\x08response\x18\x01 \x01(\r\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\x06\x12\x13\n\x0bmax_members\x18\x04 \x01(\r\x12$\n\x07members\x18\x05 \x03(\x0b\x32\x13.CMsgDOTAChatMember\x12\x46\n\x0c\x63hannel_type\x18\x06 \x01(\x0e\x32\x16.DOTAChatChannelType_t:\x18\x44OTAChannelType_Regional\x12\x45\n\x06result\x18\x07 \x01(\x0e\x32\'.CMsgDOTAJoinChatChannelResponse.Result:\x0cJOIN_SUCCESS\x12\x19\n\x11gc_initiated_join\x18\x08 \x01(\x08\x12\x17\n\x0f\x63hannel_user_id\x18\t \x01(\r\x12\x17\n\x0fwelcome_message\x18\n \x01(\t\"\xf3\x02\n\x06Result\x12\x10\n\x0cJOIN_SUCCESS\x10\x00\x12\x18\n\x14INVALID_CHANNEL_TYPE\x10\x01\x12\x15\n\x11\x41\x43\x43OUNT_NOT_FOUND\x10\x02\x12\x0e\n\nACH_FAILED\x10\x03\x12\x1d\n\x19USER_IN_TOO_MANY_CHANNELS\x10\x04\x12\x17\n\x13RATE_LIMIT_EXCEEDED\x10\x05\x12\x10\n\x0c\x43HANNEL_FULL\x10\x06\x12\x1b\n\x17\x43HANNEL_FULL_OVERFLOWED\x10\x07\x12\x16\n\x12\x46\x41ILED_TO_ADD_USER\x10\x08\x12\x19\n\x15\x43HANNEL_TYPE_DISABLED\x10\t\x12\x1e\n\x1aPRIVATE_CHAT_CREATE_FAILED\x10\n\x12\x1e\n\x1aPRIVATE_CHAT_NO_PERMISSION\x10\x0b\x12#\n\x1fPRIVATE_CHAT_CREATE_LOCK_FAILED\x10\x0c\x12\x17\n\x13PRIVATE_CHAT_KICKED\x10\r\"Y\n\x1d\x43MsgDOTAChatChannelFullUpdate\x12\x12\n\nchannel_id\x18\x01 \x01(\x06\x12$\n\x07members\x18\x02 \x03(\x0b\x32\x13.CMsgDOTAChatMember\"\x85\x01\n\x1e\x43MsgDOTAOtherJoinedChatChannel\x12\x12\n\nchannel_id\x18\x01 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x10\n\x08steam_id\x18\x03 \x01(\x06\x12\x17\n\x0f\x63hannel_user_id\x18\x04 \x01(\r\x12\x0e\n\x06status\x18\x05 \x01(\r\"]\n\x1c\x43MsgDOTAOtherLeftChatChannel\x12\x12\n\nchannel_id\x18\x01 \x01(\x06\x12\x10\n\x08steam_id\x18\x02 \x01(\x06\x12\x17\n\x0f\x63hannel_user_id\x18\x03 \x01(\r\"\xf5\x01\n\x1f\x43MsgDOTAChatChannelMemberUpdate\x12\x12\n\nchannel_id\x18\x01 \x01(\x06\x12\x16\n\x0eleft_steam_ids\x18\x02 \x03(\x06\x12\x45\n\x0ejoined_members\x18\x03 \x03(\x0b\x32-.CMsgDOTAChatChannelMemberUpdate.JoinedMember\x1a_\n\x0cJoinedMember\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63hannel_user_id\x18\x03 \x01(\r\x12\x0e\n\x06status\x18\x04 \x01(\r\" \n\x1e\x43MsgDOTARequestChatChannelList\"\xf2\x01\n&CMsgDOTARequestChatChannelListResponse\x12\x45\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x33.CMsgDOTARequestChatChannelListResponse.ChatChannel\x1a\x80\x01\n\x0b\x43hatChannel\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12\x13\n\x0bnum_members\x18\x02 \x01(\r\x12\x46\n\x0c\x63hannel_type\x18\x03 \x01(\x0e\x32\x16.DOTAChatChannelType_t:\x18\x44OTAChannelType_Regional\"-\n\x17\x43MsgDOTAChatGetUserList\x12\x12\n\nchannel_id\x18\x01 \x01(\x06\"\xca\x01\n\x1f\x43MsgDOTAChatGetUserListResponse\x12\x12\n\nchannel_id\x18\x01 \x01(\x06\x12\x38\n\x07members\x18\x02 \x03(\x0b\x32\'.CMsgDOTAChatGetUserListResponse.Member\x1aY\n\x06Member\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63hannel_user_id\x18\x03 \x01(\r\x12\x0e\n\x06status\x18\x04 \x01(\r\"z\n\x1a\x43MsgDOTAChatGetMemberCount\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12\x46\n\x0c\x63hannel_type\x18\x02 \x01(\x0e\x32\x16.DOTAChatChannelType_t:\x18\x44OTAChannelType_Regional\"\x98\x01\n\"CMsgDOTAChatGetMemberCountResponse\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12\x46\n\x0c\x63hannel_type\x18\x02 \x01(\x0e\x32\x16.DOTAChatChannelType_t:\x18\x44OTAChannelType_Regional\x12\x14\n\x0cmember_count\x18\x03 \x01(\r\"\xd9\x01\n\x1a\x43MsgDOTAChatRegionsEnabled\x12\x1a\n\x12\x65nable_all_regions\x18\x01 \x01(\x08\x12;\n\x0f\x65nabled_regions\x18\x02 \x03(\x0b\x32\".CMsgDOTAChatRegionsEnabled.Region\x1a\x62\n\x06Region\x12\x14\n\x0cmin_latitude\x18\x01 \x01(\x02\x12\x14\n\x0cmax_latitude\x18\x02 \x01(\x02\x12\x15\n\rmin_longitude\x18\x03 \x01(\x02\x12\x15\n\rmax_longitude\x18\x04 \x01(\x02\x42\x05H\x01\x90\x01\x00')
  ,
  dependencies=[dota__shared__enums__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CMSGGCTOCLIENTPRIVATECHATRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgGCToClientPrivateChatResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_CREATION_LOCK', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_SQL_TRANSACTION', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_SDO_LOAD', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NO_PERMISSION', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_ALREADY_MEMBER', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NOT_A_MEMBER', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NO_REMAINING_ADMINS', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NO_ROOM', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_CREATION_RATE_LIMITED', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_UNKNOWN_CHANNEL_NAME', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_UNKNOWN_USER', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_UNKNOWN_ERROR', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_CANNOT_KICK_ADMIN', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_ALREADY_ADMIN', index=14, number=15,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=609,
  serialized_end=1023,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTPRIVATECHATRESPONSE_RESULT)

_CMSGDOTAJOINCHATCHANNELRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgDOTAJoinChatChannelResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='JOIN_SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CHANNEL_TYPE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCOUNT_NOT_FOUND', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACH_FAILED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_IN_TOO_MANY_CHANNELS', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RATE_LIMIT_EXCEEDED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_FULL', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_FULL_OVERFLOWED', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TO_ADD_USER', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_TYPE_DISABLED', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRIVATE_CHAT_CREATE_FAILED', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRIVATE_CHAT_NO_PERMISSION', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRIVATE_CHAT_CREATE_LOCK_FAILED', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRIVATE_CHAT_KICKED', index=13, number=13,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2946,
  serialized_end=3317,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAJOINCHATCHANNELRESPONSE_RESULT)


_CMSGCLIENTTOGCPRIVATECHATINVITE = _descriptor.Descriptor(
  name='CMsgClientToGCPrivateChatInvite',
  full_name='CMsgClientToGCPrivateChatInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='private_chat_channel_name', full_name='CMsgClientToGCPrivateChatInvite.private_chat_channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invited_account_id', full_name='CMsgClientToGCPrivateChatInvite.invited_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=158,
)


_CMSGCLIENTTOGCPRIVATECHATKICK = _descriptor.Descriptor(
  name='CMsgClientToGCPrivateChatKick',
  full_name='CMsgClientToGCPrivateChatKick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='private_chat_channel_name', full_name='CMsgClientToGCPrivateChatKick.private_chat_channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kick_account_id', full_name='CMsgClientToGCPrivateChatKick.kick_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=251,
)


_CMSGCLIENTTOGCPRIVATECHATPROMOTE = _descriptor.Descriptor(
  name='CMsgClientToGCPrivateChatPromote',
  full_name='CMsgClientToGCPrivateChatPromote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='private_chat_channel_name', full_name='CMsgClientToGCPrivateChatPromote.private_chat_channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='promote_account_id', full_name='CMsgClientToGCPrivateChatPromote.promote_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=350,
)


_CMSGCLIENTTOGCPRIVATECHATDEMOTE = _descriptor.Descriptor(
  name='CMsgClientToGCPrivateChatDemote',
  full_name='CMsgClientToGCPrivateChatDemote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='private_chat_channel_name', full_name='CMsgClientToGCPrivateChatDemote.private_chat_channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='demote_account_id', full_name='CMsgClientToGCPrivateChatDemote.demote_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=447,
)


_CMSGGCTOCLIENTPRIVATECHATRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientPrivateChatResponse',
  full_name='CMsgGCToClientPrivateChatResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='private_chat_channel_name', full_name='CMsgGCToClientPrivateChatResponse.private_chat_channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCToClientPrivateChatResponse.result', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='CMsgGCToClientPrivateChatResponse.username', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCTOCLIENTPRIVATECHATRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=1023,
)


_CMSGCLIENTTOGCPRIVATECHATINFOREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCPrivateChatInfoRequest',
  full_name='CMsgClientToGCPrivateChatInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='private_chat_channel_name', full_name='CMsgClientToGCPrivateChatInfoRequest.private_chat_channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1025,
  serialized_end=1098,
)


_CMSGGCTOCLIENTPRIVATECHATINFORESPONSE_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='CMsgGCToClientPrivateChatInfoResponse.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToClientPrivateChatInfoResponse.Member.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgGCToClientPrivateChatInfoResponse.Member.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgGCToClientPrivateChatInfoResponse.Member.status', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1339,
)

_CMSGGCTOCLIENTPRIVATECHATINFORESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientPrivateChatInfoResponse',
  full_name='CMsgGCToClientPrivateChatInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='private_chat_channel_name', full_name='CMsgGCToClientPrivateChatInfoResponse.private_chat_channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgGCToClientPrivateChatInfoResponse.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='creator', full_name='CMsgGCToClientPrivateChatInfoResponse.creator', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='creation_date', full_name='CMsgGCToClientPrivateChatInfoResponse.creation_date', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTPRIVATECHATINFORESPONSE_MEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1339,
)


_CMSGDOTAJOINCHATCHANNEL = _descriptor.Descriptor(
  name='CMsgDOTAJoinChatChannel',
  full_name='CMsgDOTAJoinChatChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='CMsgDOTAJoinChatChannel.channel_name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='CMsgDOTAJoinChatChannel.channel_type', index=1,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1341,
  serialized_end=1460,
)


_CMSGDOTALEAVECHATCHANNEL = _descriptor.Descriptor(
  name='CMsgDOTALeaveChatChannel',
  full_name='CMsgDOTALeaveChatChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgDOTALeaveChatChannel.channel_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1462,
  serialized_end=1508,
)


_CMSGGCCHATREPORTPUBLICSPAM = _descriptor.Descriptor(
  name='CMsgGCChatReportPublicSpam',
  full_name='CMsgGCChatReportPublicSpam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgGCChatReportPublicSpam.channel_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_user_id', full_name='CMsgGCChatReportPublicSpam.channel_user_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1510,
  serialized_end=1583,
)


_CMSGDOTACLIENTIGNOREDUSER = _descriptor.Descriptor(
  name='CMsgDOTAClientIgnoredUser',
  full_name='CMsgDOTAClientIgnoredUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignored_account_id', full_name='CMsgDOTAClientIgnoredUser.ignored_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1585,
  serialized_end=1640,
)


_CMSGDOTACHATMESSAGE_DICEROLL = _descriptor.Descriptor(
  name='DiceRoll',
  full_name='CMsgDOTAChatMessage.DiceRoll',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roll_min', full_name='CMsgDOTAChatMessage.DiceRoll.roll_min', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='roll_max', full_name='CMsgDOTAChatMessage.DiceRoll.roll_max', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAChatMessage.DiceRoll.result', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2403,
  serialized_end=2465,
)

_CMSGDOTACHATMESSAGE = _descriptor.Descriptor(
  name='CMsgDOTAChatMessage',
  full_name='CMsgDOTAChatMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAChatMessage.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgDOTAChatMessage.channel_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgDOTAChatMessage.persona_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='CMsgDOTAChatMessage.text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTAChatMessage.timestamp', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='suggest_invite_account_id', full_name='CMsgDOTAChatMessage.suggest_invite_account_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='suggest_invite_name', full_name='CMsgDOTAChatMessage.suggest_invite_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_draft_owner_account_id', full_name='CMsgDOTAChatMessage.fantasy_draft_owner_account_id', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_draft_player_account_id', full_name='CMsgDOTAChatMessage.fantasy_draft_player_account_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgDOTAChatMessage.event_id', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='suggest_invite_to_lobby', full_name='CMsgDOTAChatMessage.suggest_invite_to_lobby', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_points', full_name='CMsgDOTAChatMessage.event_points', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coin_flip', full_name='CMsgDOTAChatMessage.coin_flip', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_id', full_name='CMsgDOTAChatMessage.player_id', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='share_profile_account_id', full_name='CMsgDOTAChatMessage.share_profile_account_id', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_user_id', full_name='CMsgDOTAChatMessage.channel_user_id', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dice_roll', full_name='CMsgDOTAChatMessage.dice_roll', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='share_party_id', full_name='CMsgDOTAChatMessage.share_party_id', index=17,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='share_lobby_id', full_name='CMsgDOTAChatMessage.share_lobby_id', index=18,
      number=19, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='share_lobby_custom_game_id', full_name='CMsgDOTAChatMessage.share_lobby_custom_game_id', index=19,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='share_lobby_passkey', full_name='CMsgDOTAChatMessage.share_lobby_passkey', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private_chat_channel_id', full_name='CMsgDOTAChatMessage.private_chat_channel_id', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgDOTAChatMessage.status', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='battle_cup_victory', full_name='CMsgDOTAChatMessage.battle_cup_victory', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='badge_level', full_name='CMsgDOTAChatMessage.badge_level', index=24,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='suggest_pick_hero_id', full_name='CMsgDOTAChatMessage.suggest_pick_hero_id', index=25,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='suggest_pick_hero_role', full_name='CMsgDOTAChatMessage.suggest_pick_hero_role', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTACHATMESSAGE_DICEROLL, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1643,
  serialized_end=2465,
)


_CMSGDOTACHATMEMBER = _descriptor.Descriptor(
  name='CMsgDOTAChatMember',
  full_name='CMsgDOTAChatMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgDOTAChatMember.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgDOTAChatMember.persona_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_user_id', full_name='CMsgDOTAChatMember.channel_user_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgDOTAChatMember.status', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2467,
  serialized_end=2568,
)


_CMSGDOTAJOINCHATCHANNELRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAJoinChatChannelResponse',
  full_name='CMsgDOTAJoinChatChannelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgDOTAJoinChatChannelResponse.response', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='CMsgDOTAJoinChatChannelResponse.channel_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgDOTAJoinChatChannelResponse.channel_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgDOTAJoinChatChannelResponse.max_members', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgDOTAJoinChatChannelResponse.members', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='CMsgDOTAJoinChatChannelResponse.channel_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAJoinChatChannelResponse.result', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gc_initiated_join', full_name='CMsgDOTAJoinChatChannelResponse.gc_initiated_join', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_user_id', full_name='CMsgDOTAJoinChatChannelResponse.channel_user_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='welcome_message', full_name='CMsgDOTAJoinChatChannelResponse.welcome_message', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAJOINCHATCHANNELRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2571,
  serialized_end=3317,
)


_CMSGDOTACHATCHANNELFULLUPDATE = _descriptor.Descriptor(
  name='CMsgDOTAChatChannelFullUpdate',
  full_name='CMsgDOTAChatChannelFullUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgDOTAChatChannelFullUpdate.channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgDOTAChatChannelFullUpdate.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3319,
  serialized_end=3408,
)


_CMSGDOTAOTHERJOINEDCHATCHANNEL = _descriptor.Descriptor(
  name='CMsgDOTAOtherJoinedChatChannel',
  full_name='CMsgDOTAOtherJoinedChatChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgDOTAOtherJoinedChatChannel.channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgDOTAOtherJoinedChatChannel.persona_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgDOTAOtherJoinedChatChannel.steam_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_user_id', full_name='CMsgDOTAOtherJoinedChatChannel.channel_user_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgDOTAOtherJoinedChatChannel.status', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3411,
  serialized_end=3544,
)


_CMSGDOTAOTHERLEFTCHATCHANNEL = _descriptor.Descriptor(
  name='CMsgDOTAOtherLeftChatChannel',
  full_name='CMsgDOTAOtherLeftChatChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgDOTAOtherLeftChatChannel.channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgDOTAOtherLeftChatChannel.steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_user_id', full_name='CMsgDOTAOtherLeftChatChannel.channel_user_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3546,
  serialized_end=3639,
)


_CMSGDOTACHATCHANNELMEMBERUPDATE_JOINEDMEMBER = _descriptor.Descriptor(
  name='JoinedMember',
  full_name='CMsgDOTAChatChannelMemberUpdate.JoinedMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgDOTAChatChannelMemberUpdate.JoinedMember.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgDOTAChatChannelMemberUpdate.JoinedMember.persona_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_user_id', full_name='CMsgDOTAChatChannelMemberUpdate.JoinedMember.channel_user_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgDOTAChatChannelMemberUpdate.JoinedMember.status', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3792,
  serialized_end=3887,
)

_CMSGDOTACHATCHANNELMEMBERUPDATE = _descriptor.Descriptor(
  name='CMsgDOTAChatChannelMemberUpdate',
  full_name='CMsgDOTAChatChannelMemberUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgDOTAChatChannelMemberUpdate.channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='left_steam_ids', full_name='CMsgDOTAChatChannelMemberUpdate.left_steam_ids', index=1,
      number=2, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='joined_members', full_name='CMsgDOTAChatChannelMemberUpdate.joined_members', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTACHATCHANNELMEMBERUPDATE_JOINEDMEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3642,
  serialized_end=3887,
)


_CMSGDOTAREQUESTCHATCHANNELLIST = _descriptor.Descriptor(
  name='CMsgDOTARequestChatChannelList',
  full_name='CMsgDOTARequestChatChannelList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3889,
  serialized_end=3921,
)


_CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE_CHATCHANNEL = _descriptor.Descriptor(
  name='ChatChannel',
  full_name='CMsgDOTARequestChatChannelListResponse.ChatChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='CMsgDOTARequestChatChannelListResponse.ChatChannel.channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_members', full_name='CMsgDOTARequestChatChannelListResponse.ChatChannel.num_members', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='CMsgDOTARequestChatChannelListResponse.ChatChannel.channel_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4038,
  serialized_end=4166,
)

_CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTARequestChatChannelListResponse',
  full_name='CMsgDOTARequestChatChannelListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='CMsgDOTARequestChatChannelListResponse.channels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE_CHATCHANNEL, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3924,
  serialized_end=4166,
)


_CMSGDOTACHATGETUSERLIST = _descriptor.Descriptor(
  name='CMsgDOTAChatGetUserList',
  full_name='CMsgDOTAChatGetUserList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgDOTAChatGetUserList.channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4168,
  serialized_end=4213,
)


_CMSGDOTACHATGETUSERLISTRESPONSE_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='CMsgDOTAChatGetUserListResponse.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgDOTAChatGetUserListResponse.Member.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgDOTAChatGetUserListResponse.Member.persona_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_user_id', full_name='CMsgDOTAChatGetUserListResponse.Member.channel_user_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgDOTAChatGetUserListResponse.Member.status', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4329,
  serialized_end=4418,
)

_CMSGDOTACHATGETUSERLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAChatGetUserListResponse',
  full_name='CMsgDOTAChatGetUserListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgDOTAChatGetUserListResponse.channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgDOTAChatGetUserListResponse.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTACHATGETUSERLISTRESPONSE_MEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4216,
  serialized_end=4418,
)


_CMSGDOTACHATGETMEMBERCOUNT = _descriptor.Descriptor(
  name='CMsgDOTAChatGetMemberCount',
  full_name='CMsgDOTAChatGetMemberCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='CMsgDOTAChatGetMemberCount.channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='CMsgDOTAChatGetMemberCount.channel_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4420,
  serialized_end=4542,
)


_CMSGDOTACHATGETMEMBERCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAChatGetMemberCountResponse',
  full_name='CMsgDOTAChatGetMemberCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='CMsgDOTAChatGetMemberCountResponse.channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='CMsgDOTAChatGetMemberCountResponse.channel_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_count', full_name='CMsgDOTAChatGetMemberCountResponse.member_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4545,
  serialized_end=4697,
)


_CMSGDOTACHATREGIONSENABLED_REGION = _descriptor.Descriptor(
  name='Region',
  full_name='CMsgDOTAChatRegionsEnabled.Region',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_latitude', full_name='CMsgDOTAChatRegionsEnabled.Region.min_latitude', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_latitude', full_name='CMsgDOTAChatRegionsEnabled.Region.max_latitude', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_longitude', full_name='CMsgDOTAChatRegionsEnabled.Region.min_longitude', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_longitude', full_name='CMsgDOTAChatRegionsEnabled.Region.max_longitude', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4819,
  serialized_end=4917,
)

_CMSGDOTACHATREGIONSENABLED = _descriptor.Descriptor(
  name='CMsgDOTAChatRegionsEnabled',
  full_name='CMsgDOTAChatRegionsEnabled',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable_all_regions', full_name='CMsgDOTAChatRegionsEnabled.enable_all_regions', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enabled_regions', full_name='CMsgDOTAChatRegionsEnabled.enabled_regions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTACHATREGIONSENABLED_REGION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4700,
  serialized_end=4917,
)

_CMSGGCTOCLIENTPRIVATECHATRESPONSE.fields_by_name['result'].enum_type = _CMSGGCTOCLIENTPRIVATECHATRESPONSE_RESULT
_CMSGGCTOCLIENTPRIVATECHATRESPONSE_RESULT.containing_type = _CMSGGCTOCLIENTPRIVATECHATRESPONSE
_CMSGGCTOCLIENTPRIVATECHATINFORESPONSE_MEMBER.containing_type = _CMSGGCTOCLIENTPRIVATECHATINFORESPONSE
_CMSGGCTOCLIENTPRIVATECHATINFORESPONSE.fields_by_name['members'].message_type = _CMSGGCTOCLIENTPRIVATECHATINFORESPONSE_MEMBER
_CMSGDOTAJOINCHATCHANNEL.fields_by_name['channel_type'].enum_type = dota__shared__enums__pb2._DOTACHATCHANNELTYPE_T
_CMSGDOTACHATMESSAGE_DICEROLL.containing_type = _CMSGDOTACHATMESSAGE
_CMSGDOTACHATMESSAGE.fields_by_name['dice_roll'].message_type = _CMSGDOTACHATMESSAGE_DICEROLL
_CMSGDOTAJOINCHATCHANNELRESPONSE.fields_by_name['members'].message_type = _CMSGDOTACHATMEMBER
_CMSGDOTAJOINCHATCHANNELRESPONSE.fields_by_name['channel_type'].enum_type = dota__shared__enums__pb2._DOTACHATCHANNELTYPE_T
_CMSGDOTAJOINCHATCHANNELRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAJOINCHATCHANNELRESPONSE_RESULT
_CMSGDOTAJOINCHATCHANNELRESPONSE_RESULT.containing_type = _CMSGDOTAJOINCHATCHANNELRESPONSE
_CMSGDOTACHATCHANNELFULLUPDATE.fields_by_name['members'].message_type = _CMSGDOTACHATMEMBER
_CMSGDOTACHATCHANNELMEMBERUPDATE_JOINEDMEMBER.containing_type = _CMSGDOTACHATCHANNELMEMBERUPDATE
_CMSGDOTACHATCHANNELMEMBERUPDATE.fields_by_name['joined_members'].message_type = _CMSGDOTACHATCHANNELMEMBERUPDATE_JOINEDMEMBER
_CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE_CHATCHANNEL.fields_by_name['channel_type'].enum_type = dota__shared__enums__pb2._DOTACHATCHANNELTYPE_T
_CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE_CHATCHANNEL.containing_type = _CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE
_CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE.fields_by_name['channels'].message_type = _CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE_CHATCHANNEL
_CMSGDOTACHATGETUSERLISTRESPONSE_MEMBER.containing_type = _CMSGDOTACHATGETUSERLISTRESPONSE
_CMSGDOTACHATGETUSERLISTRESPONSE.fields_by_name['members'].message_type = _CMSGDOTACHATGETUSERLISTRESPONSE_MEMBER
_CMSGDOTACHATGETMEMBERCOUNT.fields_by_name['channel_type'].enum_type = dota__shared__enums__pb2._DOTACHATCHANNELTYPE_T
_CMSGDOTACHATGETMEMBERCOUNTRESPONSE.fields_by_name['channel_type'].enum_type = dota__shared__enums__pb2._DOTACHATCHANNELTYPE_T
_CMSGDOTACHATREGIONSENABLED_REGION.containing_type = _CMSGDOTACHATREGIONSENABLED
_CMSGDOTACHATREGIONSENABLED.fields_by_name['enabled_regions'].message_type = _CMSGDOTACHATREGIONSENABLED_REGION
DESCRIPTOR.message_types_by_name['CMsgClientToGCPrivateChatInvite'] = _CMSGCLIENTTOGCPRIVATECHATINVITE
DESCRIPTOR.message_types_by_name['CMsgClientToGCPrivateChatKick'] = _CMSGCLIENTTOGCPRIVATECHATKICK
DESCRIPTOR.message_types_by_name['CMsgClientToGCPrivateChatPromote'] = _CMSGCLIENTTOGCPRIVATECHATPROMOTE
DESCRIPTOR.message_types_by_name['CMsgClientToGCPrivateChatDemote'] = _CMSGCLIENTTOGCPRIVATECHATDEMOTE
DESCRIPTOR.message_types_by_name['CMsgGCToClientPrivateChatResponse'] = _CMSGGCTOCLIENTPRIVATECHATRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCPrivateChatInfoRequest'] = _CMSGCLIENTTOGCPRIVATECHATINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientPrivateChatInfoResponse'] = _CMSGGCTOCLIENTPRIVATECHATINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAJoinChatChannel'] = _CMSGDOTAJOINCHATCHANNEL
DESCRIPTOR.message_types_by_name['CMsgDOTALeaveChatChannel'] = _CMSGDOTALEAVECHATCHANNEL
DESCRIPTOR.message_types_by_name['CMsgGCChatReportPublicSpam'] = _CMSGGCCHATREPORTPUBLICSPAM
DESCRIPTOR.message_types_by_name['CMsgDOTAClientIgnoredUser'] = _CMSGDOTACLIENTIGNOREDUSER
DESCRIPTOR.message_types_by_name['CMsgDOTAChatMessage'] = _CMSGDOTACHATMESSAGE
DESCRIPTOR.message_types_by_name['CMsgDOTAChatMember'] = _CMSGDOTACHATMEMBER
DESCRIPTOR.message_types_by_name['CMsgDOTAJoinChatChannelResponse'] = _CMSGDOTAJOINCHATCHANNELRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAChatChannelFullUpdate'] = _CMSGDOTACHATCHANNELFULLUPDATE
DESCRIPTOR.message_types_by_name['CMsgDOTAOtherJoinedChatChannel'] = _CMSGDOTAOTHERJOINEDCHATCHANNEL
DESCRIPTOR.message_types_by_name['CMsgDOTAOtherLeftChatChannel'] = _CMSGDOTAOTHERLEFTCHATCHANNEL
DESCRIPTOR.message_types_by_name['CMsgDOTAChatChannelMemberUpdate'] = _CMSGDOTACHATCHANNELMEMBERUPDATE
DESCRIPTOR.message_types_by_name['CMsgDOTARequestChatChannelList'] = _CMSGDOTAREQUESTCHATCHANNELLIST
DESCRIPTOR.message_types_by_name['CMsgDOTARequestChatChannelListResponse'] = _CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAChatGetUserList'] = _CMSGDOTACHATGETUSERLIST
DESCRIPTOR.message_types_by_name['CMsgDOTAChatGetUserListResponse'] = _CMSGDOTACHATGETUSERLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAChatGetMemberCount'] = _CMSGDOTACHATGETMEMBERCOUNT
DESCRIPTOR.message_types_by_name['CMsgDOTAChatGetMemberCountResponse'] = _CMSGDOTACHATGETMEMBERCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAChatRegionsEnabled'] = _CMSGDOTACHATREGIONSENABLED

CMsgClientToGCPrivateChatInvite = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPrivateChatInvite', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPRIVATECHATINVITE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCPrivateChatInvite)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPrivateChatInvite)

CMsgClientToGCPrivateChatKick = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPrivateChatKick', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPRIVATECHATKICK,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCPrivateChatKick)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPrivateChatKick)

CMsgClientToGCPrivateChatPromote = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPrivateChatPromote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPRIVATECHATPROMOTE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCPrivateChatPromote)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPrivateChatPromote)

CMsgClientToGCPrivateChatDemote = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPrivateChatDemote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPRIVATECHATDEMOTE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCPrivateChatDemote)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPrivateChatDemote)

CMsgGCToClientPrivateChatResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPrivateChatResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPRIVATECHATRESPONSE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientPrivateChatResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPrivateChatResponse)

CMsgClientToGCPrivateChatInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPrivateChatInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPRIVATECHATINFOREQUEST,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCPrivateChatInfoRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPrivateChatInfoRequest)

CMsgGCToClientPrivateChatInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPrivateChatInfoResponse', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTPRIVATECHATINFORESPONSE_MEMBER,
    __module__ = 'dota_gcmessages_client_chat_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientPrivateChatInfoResponse.Member)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTPRIVATECHATINFORESPONSE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientPrivateChatInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPrivateChatInfoResponse)
_sym_db.RegisterMessage(CMsgGCToClientPrivateChatInfoResponse.Member)

CMsgDOTAJoinChatChannel = _reflection.GeneratedProtocolMessageType('CMsgDOTAJoinChatChannel', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAJOINCHATCHANNEL,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAJoinChatChannel)
  ))
_sym_db.RegisterMessage(CMsgDOTAJoinChatChannel)

CMsgDOTALeaveChatChannel = _reflection.GeneratedProtocolMessageType('CMsgDOTALeaveChatChannel', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALEAVECHATCHANNEL,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALeaveChatChannel)
  ))
_sym_db.RegisterMessage(CMsgDOTALeaveChatChannel)

CMsgGCChatReportPublicSpam = _reflection.GeneratedProtocolMessageType('CMsgGCChatReportPublicSpam', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCHATREPORTPUBLICSPAM,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCChatReportPublicSpam)
  ))
_sym_db.RegisterMessage(CMsgGCChatReportPublicSpam)

CMsgDOTAClientIgnoredUser = _reflection.GeneratedProtocolMessageType('CMsgDOTAClientIgnoredUser', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACLIENTIGNOREDUSER,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAClientIgnoredUser)
  ))
_sym_db.RegisterMessage(CMsgDOTAClientIgnoredUser)

CMsgDOTAChatMessage = _reflection.GeneratedProtocolMessageType('CMsgDOTAChatMessage', (_message.Message,), dict(

  DiceRoll = _reflection.GeneratedProtocolMessageType('DiceRoll', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACHATMESSAGE_DICEROLL,
    __module__ = 'dota_gcmessages_client_chat_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAChatMessage.DiceRoll)
    ))
  ,
  DESCRIPTOR = _CMSGDOTACHATMESSAGE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChatMessage)
  ))
_sym_db.RegisterMessage(CMsgDOTAChatMessage)
_sym_db.RegisterMessage(CMsgDOTAChatMessage.DiceRoll)

CMsgDOTAChatMember = _reflection.GeneratedProtocolMessageType('CMsgDOTAChatMember', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACHATMEMBER,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChatMember)
  ))
_sym_db.RegisterMessage(CMsgDOTAChatMember)

CMsgDOTAJoinChatChannelResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAJoinChatChannelResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAJOINCHATCHANNELRESPONSE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAJoinChatChannelResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAJoinChatChannelResponse)

CMsgDOTAChatChannelFullUpdate = _reflection.GeneratedProtocolMessageType('CMsgDOTAChatChannelFullUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACHATCHANNELFULLUPDATE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChatChannelFullUpdate)
  ))
_sym_db.RegisterMessage(CMsgDOTAChatChannelFullUpdate)

CMsgDOTAOtherJoinedChatChannel = _reflection.GeneratedProtocolMessageType('CMsgDOTAOtherJoinedChatChannel', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAOTHERJOINEDCHATCHANNEL,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAOtherJoinedChatChannel)
  ))
_sym_db.RegisterMessage(CMsgDOTAOtherJoinedChatChannel)

CMsgDOTAOtherLeftChatChannel = _reflection.GeneratedProtocolMessageType('CMsgDOTAOtherLeftChatChannel', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAOTHERLEFTCHATCHANNEL,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAOtherLeftChatChannel)
  ))
_sym_db.RegisterMessage(CMsgDOTAOtherLeftChatChannel)

CMsgDOTAChatChannelMemberUpdate = _reflection.GeneratedProtocolMessageType('CMsgDOTAChatChannelMemberUpdate', (_message.Message,), dict(

  JoinedMember = _reflection.GeneratedProtocolMessageType('JoinedMember', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACHATCHANNELMEMBERUPDATE_JOINEDMEMBER,
    __module__ = 'dota_gcmessages_client_chat_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAChatChannelMemberUpdate.JoinedMember)
    ))
  ,
  DESCRIPTOR = _CMSGDOTACHATCHANNELMEMBERUPDATE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChatChannelMemberUpdate)
  ))
_sym_db.RegisterMessage(CMsgDOTAChatChannelMemberUpdate)
_sym_db.RegisterMessage(CMsgDOTAChatChannelMemberUpdate.JoinedMember)

CMsgDOTARequestChatChannelList = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestChatChannelList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREQUESTCHATCHANNELLIST,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARequestChatChannelList)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestChatChannelList)

CMsgDOTARequestChatChannelListResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestChatChannelListResponse', (_message.Message,), dict(

  ChatChannel = _reflection.GeneratedProtocolMessageType('ChatChannel', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE_CHATCHANNEL,
    __module__ = 'dota_gcmessages_client_chat_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARequestChatChannelListResponse.ChatChannel)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAREQUESTCHATCHANNELLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARequestChatChannelListResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestChatChannelListResponse)
_sym_db.RegisterMessage(CMsgDOTARequestChatChannelListResponse.ChatChannel)

CMsgDOTAChatGetUserList = _reflection.GeneratedProtocolMessageType('CMsgDOTAChatGetUserList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACHATGETUSERLIST,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChatGetUserList)
  ))
_sym_db.RegisterMessage(CMsgDOTAChatGetUserList)

CMsgDOTAChatGetUserListResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAChatGetUserListResponse', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACHATGETUSERLISTRESPONSE_MEMBER,
    __module__ = 'dota_gcmessages_client_chat_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAChatGetUserListResponse.Member)
    ))
  ,
  DESCRIPTOR = _CMSGDOTACHATGETUSERLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChatGetUserListResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAChatGetUserListResponse)
_sym_db.RegisterMessage(CMsgDOTAChatGetUserListResponse.Member)

CMsgDOTAChatGetMemberCount = _reflection.GeneratedProtocolMessageType('CMsgDOTAChatGetMemberCount', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACHATGETMEMBERCOUNT,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChatGetMemberCount)
  ))
_sym_db.RegisterMessage(CMsgDOTAChatGetMemberCount)

CMsgDOTAChatGetMemberCountResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAChatGetMemberCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACHATGETMEMBERCOUNTRESPONSE,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChatGetMemberCountResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAChatGetMemberCountResponse)

CMsgDOTAChatRegionsEnabled = _reflection.GeneratedProtocolMessageType('CMsgDOTAChatRegionsEnabled', (_message.Message,), dict(

  Region = _reflection.GeneratedProtocolMessageType('Region', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACHATREGIONSENABLED_REGION,
    __module__ = 'dota_gcmessages_client_chat_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAChatRegionsEnabled.Region)
    ))
  ,
  DESCRIPTOR = _CMSGDOTACHATREGIONSENABLED,
  __module__ = 'dota_gcmessages_client_chat_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAChatRegionsEnabled)
  ))
_sym_db.RegisterMessage(CMsgDOTAChatRegionsEnabled)
_sym_db.RegisterMessage(CMsgDOTAChatRegionsEnabled.Region)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_client_enums.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_client_enums.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x17\x64ota_client_enums.proto*^\n\x13\x45TournamentTemplate\x12\x1e\n\x1ak_ETournamentTemplate_None\x10\x00\x12\'\n#k_ETournamentTemplate_AutomatedWin3\x10\x01*\xa8\x03\n\x14\x45TournamentGameState\x12\"\n\x1ek_ETournamentGameState_Unknown\x10\x00\x12#\n\x1fk_ETournamentGameState_Canceled\x10\x01\x12$\n k_ETournamentGameState_Scheduled\x10\x02\x12!\n\x1dk_ETournamentGameState_Active\x10\x03\x12%\n!k_ETournamentGameState_RadVictory\x10\x14\x12&\n\"k_ETournamentGameState_DireVictory\x10\x15\x12.\n*k_ETournamentGameState_RadVictoryByForfeit\x10\x16\x12/\n+k_ETournamentGameState_DireVictoryByForfeit\x10\x17\x12(\n$k_ETournamentGameState_ServerFailure\x10(\x12$\n k_ETournamentGameState_NotNeeded\x10)*\xe7\x06\n\x14\x45TournamentTeamState\x12\"\n\x1ek_ETournamentTeamState_Unknown\x10\x00\x12 \n\x1ck_ETournamentTeamState_Node1\x10\x01\x12#\n\x1ek_ETournamentTeamState_NodeMax\x10\x80\x08\x12&\n!k_ETournamentTeamState_Eliminated\x10\xb3m\x12%\n k_ETournamentTeamState_Forfeited\x10\xb4m\x12\'\n\"k_ETournamentTeamState_Finished1st\x10\x99u\x12\'\n\"k_ETournamentTeamState_Finished2nd\x10\x9au\x12\'\n\"k_ETournamentTeamState_Finished3rd\x10\x9bu\x12\'\n\"k_ETournamentTeamState_Finished4th\x10\x9cu\x12\'\n\"k_ETournamentTeamState_Finished5th\x10\x9du\x12\'\n\"k_ETournamentTeamState_Finished6th\x10\x9eu\x12\'\n\"k_ETournamentTeamState_Finished7th\x10\x9fu\x12\'\n\"k_ETournamentTeamState_Finished8th\x10\xa0u\x12\'\n\"k_ETournamentTeamState_Finished9th\x10\xa1u\x12(\n#k_ETournamentTeamState_Finished10th\x10\xa2u\x12(\n#k_ETournamentTeamState_Finished11th\x10\xa3u\x12(\n#k_ETournamentTeamState_Finished12th\x10\xa4u\x12(\n#k_ETournamentTeamState_Finished13th\x10\xa5u\x12(\n#k_ETournamentTeamState_Finished14th\x10\xa6u\x12(\n#k_ETournamentTeamState_Finished15th\x10\xa7u\x12(\n#k_ETournamentTeamState_Finished16th\x10\xa8u*\x86\x03\n\x10\x45TournamentState\x12\x1e\n\x1ak_ETournamentState_Unknown\x10\x00\x12&\n\"k_ETournamentState_CanceledByAdmin\x10\x01\x12 \n\x1ck_ETournamentState_Completed\x10\x02\x12\x1d\n\x19k_ETournamentState_Merged\x10\x03\x12$\n k_ETournamentState_ServerFailure\x10\x04\x12$\n k_ETournamentState_TeamAbandoned\x10\x05\x12)\n%k_ETournamentState_TeamTimeoutForfeit\x10\x06\x12(\n$k_ETournamentState_TeamTimeoutRefund\x10\x07\x12!\n\x1dk_ETournamentState_InProgress\x10\x64\x12%\n!k_ETournamentState_WaitingToMerge\x10\x65*\xcc\x04\n\x14\x45TournamentNodeState\x12\"\n\x1ek_ETournamentNodeState_Unknown\x10\x00\x12#\n\x1fk_ETournamentNodeState_Canceled\x10\x01\x12.\n*k_ETournamentNodeState_TeamsNotYetAssigned\x10\x02\x12)\n%k_ETournamentNodeState_InBetweenGames\x10\x03\x12)\n%k_ETournamentNodeState_GameInProgress\x10\x04\x12 \n\x1ck_ETournamentNodeState_A_Won\x10\x05\x12 \n\x1ck_ETournamentNodeState_B_Won\x10\x06\x12)\n%k_ETournamentNodeState_A_WonByForfeit\x10\x07\x12)\n%k_ETournamentNodeState_B_WonByForfeit\x10\x08\x12 \n\x1ck_ETournamentNodeState_A_Bye\x10\t\x12&\n\"k_ETournamentNodeState_A_Abandoned\x10\n\x12(\n$k_ETournamentNodeState_ServerFailure\x10\x0b\x12+\n\'k_ETournamentNodeState_A_TimeoutForfeit\x10\x0c\x12*\n&k_ETournamentNodeState_A_TimeoutRefund\x10\r*\xc7\x03\n\x15\x45\x44OTAGroupMergeResult\x12\x1e\n\x1ak_EDOTAGroupMergeResult_OK\x10\x00\x12*\n&k_EDOTAGroupMergeResult_FAILED_GENERIC\x10\x01\x12&\n\"k_EDOTAGroupMergeResult_NOT_LEADER\x10\x02\x12,\n(k_EDOTAGroupMergeResult_TOO_MANY_PLAYERS\x10\x03\x12,\n(k_EDOTAGroupMergeResult_TOO_MANY_COACHES\x10\x04\x12+\n\'k_EDOTAGroupMergeResult_ENGINE_MISMATCH\x10\x05\x12)\n%k_EDOTAGroupMergeResult_NO_SUCH_GROUP\x10\x06\x12\x30\n,k_EDOTAGroupMergeResult_OTHER_GROUP_NOT_OPEN\x10\x07\x12+\n\'k_EDOTAGroupMergeResult_ALREADY_INVITED\x10\x08\x12\'\n#k_EDOTAGroupMergeResult_NOT_INVITED\x10\tB\x05H\x01\x90\x01\x00')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_ETOURNAMENTTEMPLATE = _descriptor.EnumDescriptor(
  name='ETournamentTemplate',
  full_name='ETournamentTemplate',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTemplate_None', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTemplate_AutomatedWin3', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=27,
  serialized_end=121,
)
_sym_db.RegisterEnumDescriptor(_ETOURNAMENTTEMPLATE)

ETournamentTemplate = enum_type_wrapper.EnumTypeWrapper(_ETOURNAMENTTEMPLATE)
_ETOURNAMENTGAMESTATE = _descriptor.EnumDescriptor(
  name='ETournamentGameState',
  full_name='ETournamentGameState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentGameState_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentGameState_Canceled', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentGameState_Scheduled', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentGameState_Active', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentGameState_RadVictory', index=4, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentGameState_DireVictory', index=5, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentGameState_RadVictoryByForfeit', index=6, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentGameState_DireVictoryByForfeit', index=7, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentGameState_ServerFailure', index=8, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentGameState_NotNeeded', index=9, number=41,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=124,
  serialized_end=548,
)
_sym_db.RegisterEnumDescriptor(_ETOURNAMENTGAMESTATE)

ETournamentGameState = enum_type_wrapper.EnumTypeWrapper(_ETOURNAMENTGAMESTATE)
_ETOURNAMENTTEAMSTATE = _descriptor.EnumDescriptor(
  name='ETournamentTeamState',
  full_name='ETournamentTeamState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Node1', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_NodeMax', index=2, number=1024,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Eliminated', index=3, number=14003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Forfeited', index=4, number=14004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished1st', index=5, number=15001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished2nd', index=6, number=15002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished3rd', index=7, number=15003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished4th', index=8, number=15004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished5th', index=9, number=15005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished6th', index=10, number=15006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished7th', index=11, number=15007,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished8th', index=12, number=15008,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished9th', index=13, number=15009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished10th', index=14, number=15010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished11th', index=15, number=15011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished12th', index=16, number=15012,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished13th', index=17, number=15013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished14th', index=18, number=15014,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished15th', index=19, number=15015,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentTeamState_Finished16th', index=20, number=15016,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=551,
  serialized_end=1422,
)
_sym_db.RegisterEnumDescriptor(_ETOURNAMENTTEAMSTATE)

ETournamentTeamState = enum_type_wrapper.EnumTypeWrapper(_ETOURNAMENTTEAMSTATE)
_ETOURNAMENTSTATE = _descriptor.EnumDescriptor(
  name='ETournamentState',
  full_name='ETournamentState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentState_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentState_CanceledByAdmin', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentState_Completed', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentState_Merged', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentState_ServerFailure', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentState_TeamAbandoned', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentState_TeamTimeoutForfeit', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentState_TeamTimeoutRefund', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentState_InProgress', index=8, number=100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentState_WaitingToMerge', index=9, number=101,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1425,
  serialized_end=1815,
)
_sym_db.RegisterEnumDescriptor(_ETOURNAMENTSTATE)

ETournamentState = enum_type_wrapper.EnumTypeWrapper(_ETOURNAMENTSTATE)
_ETOURNAMENTNODESTATE = _descriptor.EnumDescriptor(
  name='ETournamentNodeState',
  full_name='ETournamentNodeState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_Canceled', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_TeamsNotYetAssigned', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_InBetweenGames', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_GameInProgress', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_A_Won', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_B_Won', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_A_WonByForfeit', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_B_WonByForfeit', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_A_Bye', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_A_Abandoned', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_ServerFailure', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_A_TimeoutForfeit', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentNodeState_A_TimeoutRefund', index=13, number=13,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1818,
  serialized_end=2406,
)
_sym_db.RegisterEnumDescriptor(_ETOURNAMENTNODESTATE)

ETournamentNodeState = enum_type_wrapper.EnumTypeWrapper(_ETOURNAMENTNODESTATE)
_EDOTAGROUPMERGERESULT = _descriptor.EnumDescriptor(
  name='EDOTAGroupMergeResult',
  full_name='EDOTAGroupMergeResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGroupMergeResult_OK', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGroupMergeResult_FAILED_GENERIC', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGroupMergeResult_NOT_LEADER', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGroupMergeResult_TOO_MANY_PLAYERS', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGroupMergeResult_TOO_MANY_COACHES', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGroupMergeResult_ENGINE_MISMATCH', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGroupMergeResult_NO_SUCH_GROUP', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGroupMergeResult_OTHER_GROUP_NOT_OPEN', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGroupMergeResult_ALREADY_INVITED', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGroupMergeResult_NOT_INVITED', index=9, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2409,
  serialized_end=2864,
)
_sym_db.RegisterEnumDescriptor(_EDOTAGROUPMERGERESULT)

EDOTAGroupMergeResult = enum_type_wrapper.EnumTypeWrapper(_EDOTAGROUPMERGERESULT)
k_ETournamentTemplate_None = 0
k_ETournamentTemplate_AutomatedWin3 = 1
k_ETournamentGameState_Unknown = 0
k_ETournamentGameState_Canceled = 1
k_ETournamentGameState_Scheduled = 2
k_ETournamentGameState_Active = 3
k_ETournamentGameState_RadVictory = 20
k_ETournamentGameState_DireVictory = 21
k_ETournamentGameState_RadVictoryByForfeit = 22
k_ETournamentGameState_DireVictoryByForfeit = 23
k_ETournamentGameState_ServerFailure = 40
k_ETournamentGameState_NotNeeded = 41
k_ETournamentTeamState_Unknown = 0
k_ETournamentTeamState_Node1 = 1
k_ETournamentTeamState_NodeMax = 1024
k_ETournamentTeamState_Eliminated = 14003
k_ETournamentTeamState_Forfeited = 14004
k_ETournamentTeamState_Finished1st = 15001
k_ETournamentTeamState_Finished2nd = 15002
k_ETournamentTeamState_Finished3rd = 15003
k_ETournamentTeamState_Finished4th = 15004
k_ETournamentTeamState_Finished5th = 15005
k_ETournamentTeamState_Finished6th = 15006
k_ETournamentTeamState_Finished7th = 15007
k_ETournamentTeamState_Finished8th = 15008
k_ETournamentTeamState_Finished9th = 15009
k_ETournamentTeamState_Finished10th = 15010
k_ETournamentTeamState_Finished11th = 15011
k_ETournamentTeamState_Finished12th = 15012
k_ETournamentTeamState_Finished13th = 15013
k_ETournamentTeamState_Finished14th = 15014
k_ETournamentTeamState_Finished15th = 15015
k_ETournamentTeamState_Finished16th = 15016
k_ETournamentState_Unknown = 0
k_ETournamentState_CanceledByAdmin = 1
k_ETournamentState_Completed = 2
k_ETournamentState_Merged = 3
k_ETournamentState_ServerFailure = 4
k_ETournamentState_TeamAbandoned = 5
k_ETournamentState_TeamTimeoutForfeit = 6
k_ETournamentState_TeamTimeoutRefund = 7
k_ETournamentState_InProgress = 100
k_ETournamentState_WaitingToMerge = 101
k_ETournamentNodeState_Unknown = 0
k_ETournamentNodeState_Canceled = 1
k_ETournamentNodeState_TeamsNotYetAssigned = 2
k_ETournamentNodeState_InBetweenGames = 3
k_ETournamentNodeState_GameInProgress = 4
k_ETournamentNodeState_A_Won = 5
k_ETournamentNodeState_B_Won = 6
k_ETournamentNodeState_A_WonByForfeit = 7
k_ETournamentNodeState_B_WonByForfeit = 8
k_ETournamentNodeState_A_Bye = 9
k_ETournamentNodeState_A_Abandoned = 10
k_ETournamentNodeState_ServerFailure = 11
k_ETournamentNodeState_A_TimeoutForfeit = 12
k_ETournamentNodeState_A_TimeoutRefund = 13
k_EDOTAGroupMergeResult_OK = 0
k_EDOTAGroupMergeResult_FAILED_GENERIC = 1
k_EDOTAGroupMergeResult_NOT_LEADER = 2
k_EDOTAGroupMergeResult_TOO_MANY_PLAYERS = 3
k_EDOTAGroupMergeResult_TOO_MANY_COACHES = 4
k_EDOTAGroupMergeResult_ENGINE_MISMATCH = 5
k_EDOTAGroupMergeResult_NO_SUCH_GROUP = 6
k_EDOTAGroupMergeResult_OTHER_GROUP_NOT_OPEN = 7
k_EDOTAGroupMergeResult_ALREADY_INVITED = 8
k_EDOTAGroupMergeResult_NOT_INVITED = 9


DESCRIPTOR.enum_types_by_name['ETournamentTemplate'] = _ETOURNAMENTTEMPLATE
DESCRIPTOR.enum_types_by_name['ETournamentGameState'] = _ETOURNAMENTGAMESTATE
DESCRIPTOR.enum_types_by_name['ETournamentTeamState'] = _ETOURNAMENTTEAMSTATE
DESCRIPTOR.enum_types_by_name['ETournamentState'] = _ETOURNAMENTSTATE
DESCRIPTOR.enum_types_by_name['ETournamentNodeState'] = _ETOURNAMENTNODESTATE
DESCRIPTOR.enum_types_by_name['EDOTAGroupMergeResult'] = _EDOTAGROUPMERGERESULT


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
# @@protoc_insertion_point(module_scope)
